@@ -1,5 +1,5 @@
 import http
-from typing import NamedTuple, Optional, Union, final
+from typing import NamedTuple, final
 
 from souswift_core.utils import deprecated
 
@@ -21,7 +21,7 @@ class APIError(Exception):
 
     @deprecated
     @classmethod
-    def from_message(cls, message: str, status_code: Optional[int] = None):
+    def from_message(cls, message: str, status_code: int | None = None):
         self = cls(message)
         if status_code:
             self._status = status_code
@@ -44,7 +44,7 @@ class DatabaseError(Exception):
 
     @deprecated
     @classmethod
-    def from_object(cls, obj: Union[str, type]):
+    def from_object(cls, obj: str | type):
         if isinstance(obj, str):
             target = obj
         else:
