@@ -1,20 +1,18 @@
+from collections.abc import Callable
 from dataclasses import dataclass
 from enum import Enum
-from typing import Any, Callable, Optional, Union
+from typing import Any, TypeGuard
 
 from sqlalchemy import Column, Table, and_, extract, false, func, or_, true
 from sqlalchemy.orm.relationships import RelationshipProperty
 from sqlalchemy.sql.elements import BooleanClauseList
-from typing_extensions import TypeGuard
 
 from souswift_core.filters import _comparison as cp
 from souswift_core.filters.base import Filter
 from souswift_core.providers import Driver
 
 
-def _attr(
-    entity: Union[type, Table], field: str
-) -> Union[Column, RelationshipProperty]:
+def _attr(entity: type | Table, field: str) -> Column | RelationshipProperty:
     result = getattr(entity, field, None) or getattr(entity.c, field, None)
     if result is None:
         raise NotImplementedError
@@ -24,10 +22,10 @@ def _attr(
 @dataclass
 class Field(Filter):
     field: str
-    value: Optional[Any]
+    value: Any | None
     comp: cp.Comparison = cp.Equal()
     enum_value: bool = False
-    sql_func: Optional[Callable[[Column], Any]] = None
+    sql_func: Callable[[Column], Any] | None = None
 
     def similar_to(self, where: Filter) -> 'TypeGuard[Field]':
         if not isinstance(where, type(self)):
@@ -45,10 +43,10 @@ class Field(Filter):
             else:
                 self.value = self.value and self.value.name
 
-    def where(self, entity: Union[type, Table]):
+    def where(self, entity: type | Table):
         return self.attr(entity)  # type: ignore
 
-    def attr(self, entity: Union[type, Table]):
+    def attr(self, entity: type | Table):
         attr = self.retrieve_attr(entity)
         if not self:
             return True
@@ -56,7 +54,7 @@ class Field(Filter):
             attr = self.sql_func(attr)  # type: ignore
         return self.comp.compare(attr, self.value)
 
-    def retrieve_attr(self, entity: Union[type, Table]):
+    def retrieve_attr(self, entity: type | Table):
         return _attr(entity, self.field)
 
     def __bool__(self):
@@ -71,7 +69,7 @@ class FilterJoins(Filter):
     def __init__(self, *filters: Filter) -> None:
         self.filters = filters
 
-    def where(self, entity: Union[type, Table]):
+    def where(self, entity: type | Table):
         return self.operator(*(f.where(entity) for f in self.filters))
 
     def __bool__(self):
@@ -90,7 +88,7 @@ class And(FilterJoins):
         return and_
 
 
-def _entity_from_foreign(attr: Union[Column, RelationshipProperty]) -> type:
+def _entity_from_foreign(attr: Column | RelationshipProperty) -> type:
     return attr.entity.class_
 
 
@@ -120,7 +118,7 @@ class FilterIterator(Filter):
     def __bool__(self):
         return bool(self._filter)
 
-    def where(self, entity: Union[type, Table]):
+    def where(self, entity: type | Table):
         return self._filter.where(entity)
 
     def fields(self):
