@@ -9,7 +9,7 @@ from sqlalchemy.sql.elements import BooleanClauseList
 class Filter:
     _mark: str = ''
 
-    def where(self, entity: typing.Union[type, Table]):
+    def where(self, entity: type | Table):
         pass
 
     def __bool__(self):
@@ -27,6 +27,6 @@ class Filter:
 class Comparison(abc.ABC):
     @abc.abstractmethod
     def compare(
-        self, attr: typing.Union[Column, typing.Any], target: typing.Any
+        self, attr: Column | typing.Any, target: typing.Any
     ) -> typing.Union[BooleanClauseList, 'ColumnElement[Boolean]']:
         """Receives column or function and returns a sqlalchemy comparison"""
