@@ -2,11 +2,11 @@ import abc
 import importlib
 import inspect
 from pathlib import Path
-from typing import Any, Generic, Optional, TypeVar
+from typing import Any, Generic, TypeVar
 
 
 class _Finder(abc.ABC):
-    def __init__(self, path: Path, root: Path = None):
+    def __init__(self, path: Path, root: Path | None = None):
         self.path = path
         self._targets = {}
         self.root = root or path
@@ -17,7 +17,7 @@ class _Finder(abc.ABC):
         else:
             self.find_from_file()
 
-    def find_from_dir(self, path: Optional[Path] = None):
+    def find_from_dir(self, path: Path | None = None):
         if path is None:
             path = self.path
         if 'pycache' in path.name or '.pyc' in path.name:
@@ -30,7 +30,7 @@ class _Finder(abc.ABC):
                 continue
             self.find_from_file(item)
 
-    def find_from_file(self, path: Optional[Path] = None):
+    def find_from_file(self, path: Path | None = None):
         if path is None:
             path = self.path
         if not path.is_file():
