@@ -1,5 +1,5 @@
 import re
-from typing import Generic, Optional, TypeVar
+from typing import Generic, TypeVar
 
 import fastapi
 import orjson
@@ -35,15 +35,15 @@ T = TypeVar('T', bound=Model)
 
 
 class Details(FrozenModel):
-    last_id: Optional[int] = None
-    total_pages: Optional[int] = None
-    info: Optional[str] = None
-    total_left: Optional[int] = None
+    last_id: int | None = None
+    total_pages: int | None = None
+    info: str | None = None
+    total_left: int | None = None
 
 
 class BaseResponse(pydantic.generics.GenericModel, Generic[T]):
     data: list[T]
-    details: Optional[Details] = pydantic.Field(default_factory=Details)
+    details: Details | None = pydantic.Field(default_factory=Details)
 
 
 class Page(FrozenModel):
@@ -56,7 +56,3 @@ class BaseError(Model):
     path: str
     status: int
     detail: str
-
-
-class ExtendedBaseError(BaseError):
-    error_key: str
